<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.Windows.System.Power

ATTENTION: This package has been renamed to
[winui3-Microsoft.Windows.System.Power](https://pypi.org/project/winui3-Microsoft.Windows.System.Power/).
Use the new package for the latest updates.

Windows Runtime (WinRT) APIs for for the `Microsoft.Windows.System.Power` namespace.

This package provides the `winrt.microsoft.windows.system.power` module.
